<?php header('Content-type: text/html; charset=utf-8'); ?>
<?php

include_once 'calendar_functions.php';

/******************************************************************
// load viewer library
*******************************************************************/
$libraryPath = 'cmsAdmin/lib/viewer_functions.php';
$dirsToCheck = ['','../','../../','../../../','../../../../']; // add if needed: '/home/...'
foreach ($dirsToCheck as $dir) { if (@include_once("$dir$libraryPath")) { break; }}
if (!function_exists('getRecords')) { die("Couldn't load viewer library, check filepath in sourcecode."); }


// Retrieve GET parameters for view and navigation
$view  = isset($_GET['view']) ? $_GET['view'] : 'month';             // Default to 'month'
$year  = isset($_GET['year']) ? intval($_GET['year']) : date('Y');   // Default to current year
$month = isset($_GET['month']) ? intval($_GET['month']) : date('m'); // Default to current month
$week  = isset($_GET['week']) ? intval($_GET['week']) : date('W');   // Default to current week
$day   = isset($_GET['day']) ? intval($_GET['day']) : date('d');     // Default to today


// Validate and sanitize inputs for the calendar view
$allowed_views = ['month', 'week', 'day', 'year'];
if (!in_array($view, $allowed_views)) { $view = 'month'; }        // Validate the $view variable
if ($year < 1970 || $year > date('Y') + 1) { $year = date('Y'); } // Validate the year
if ($month < 1 || $month > 12) { $month = date('m'); }            // Validate the month
if ($week < 1 || $week > 53) { $week = date('W'); }               // Validate the week
if ($day < 1 || $day > 31) { $day = date('d'); }                  // Validate the day


// Determine if we're in example mode or production mode (can be based on a constant or environment variable)
$mode = 'example'; // or 'production'


// Check the execution mode
if ($mode === 'production') {

	// Create the start and end dates for the given month
	$startDate = sprintf("%04d-%02d-01 00:00:00", $year, $month); // First day of the month
	$endDate = date('Y-m-t 23:59:59', strtotime($startDate));     // Last day of the month

	// Production mode: use getRecords to fetch events from the database
    $query = "(start_date BETWEEN '$startDate' AND '$endDate') OR (end_date BETWEEN '$startDate' AND '$endDate')";

    // Load records from the 'events' table
    list($events) = getRecords(array(
        'tableName'   => 'events',
        'where'       => $query,
        'loadUploads' => true,
        'allowSearch' => false,
        'debugSql'    => false,
    ));

} else {

	// Example mode: use a static array with mock events
    $events = [
        [
            'title' => 'Annual Conference',
            'start_date' => '2024-10-21 09:00:00',
            'end_date' => '2024-10-21 17:00:00',
            'permalink' => 'annual-conference',
            'description' => 'Annual conference on technological innovations.',
            'location' => 'Main Auditorium'
        ],
        [
            'title' => 'Digital Marketing Seminar',
            'start_date' => '2024-10-22 10:00:00',
            'end_date' => '2024-10-22 15:00:00',
            'permalink' => 'digital-marketing-seminar',
            'description' => 'Seminar on the latest trends in digital marketing.',
            'location' => 'Meeting Room B'
        ],
        [
            'title' => 'Team Meeting',
            'start_date' => '2024-10-25 14:00:00',
            'end_date' => '2024-10-26 12:00:00',
            'permalink' => 'team-meeting',
            'description' => 'Weekly team meeting to discuss progress.',
            'location' => 'Conference Room C'
        ],
        [
            'title' => 'PHP Workshop',
            'start_date' => '2024-11-02 14:00:00',
            'end_date' => '2024-11-02 17:00:00',
            'permalink' => 'php-workshop',
            'description' => 'A hands-on workshop on PHP development.',
            'location' => 'Training Room D'
        ],
        [
            'title' => 'Annual Conference',
            'start_date' => '2024-12-22 09:00:00',
            'end_date' => '2024-12-23 18:00:00',
            'permalink' => 'annual-conference',
            'description' => 'Annual conference on technological innovations.',
            'location' => 'Main Auditorium'
        ]
		// Other mock events can go here
    ];
}


/******************************************************************
// Set HTTP headers for cache control
*******************************************************************/
header('Cache-Control: no-cache, no-store, must-revalidate'); // No caching allowed
header('Expires: 0'); // Set expiration to 0
header_remove('Pragma'); // Remove pragma header

?><!DOCTYPE html>
<html lang="en">
<head>
<meta charset="UTF-8">
<meta name="viewport" content="width=device-width, initial-scale=1">
<title>Calendar <?php echo date('Y'); ?></title>

<style>
	.container {
		width: 90%;
		margin: 20px auto;
	}

	.view-switcher {
		display: flex;
		gap: 10px;
		justify-content: left;
		align-items: center;
		margin: 20px auto;
		text-align: center;
	}

	.view-switcher a {
		text-decoration: none;
	}

	.view-switcher a.active {
		font-weight: bold;
	}

	.calendar-navigation {
		display: flex;
		gap: 10px;
		justify-content: center;
		align-items: center;
		margin: 20px auto;
		text-align: center;
	}

	.calendar-month {
		width: 100%;
		border-collapse: collapse;
	}

	.calendar-month th, .calendar-month td {
		width: 14.28%;
		border: 1px solid #ccc;
		padding: 10px;
		text-align: center;
		vertical-align: top;
	}

	.calendar-month .day {
		position: relative;
		min-height: 50px;
	}

	.calendar-month .day-number {
		position: absolute;
		top: 0;
		right: 0;
		padding: 5px;
		font-weight: bold;
	}

	.calendar-month .today {
		background-color: #ffeb3b;
	}

	.calendar-month .prev-month, .calendar-month .next-month {
		color: #999;
		background-color: #f5f5f5;
	}

	.calendar-month .event {
		margin-top: 5px;
		background-color: #90caf9;
		padding: 3px;
		border-radius: 3px;
	}

	.calendar-week {
		width: 100%;
		border-collapse: collapse;
		table-layout: fixed; /* Ensures fixed distribution of columns */
	}

	.calendar-week th, .calendar-week td {
		width: 40px;
		border: 1px solid #ccc;
		padding: 10px;
		text-align: center;
		word-wrap: break-word;
	}

	.calendar-week .hour {
		width: 40px; /* Fixed width for the "hour" column */
		background-color: #f9f9f9;
		text-align: center;
		padding-right: 10px;
		font-weight: bold;
	}

	/* Apply equal width to other columns */
	.calendar-week th:not(:first-child), .calendar-week td:not(:first-child) {
		width: calc((100% - 40px) / 7); /* Equal width for other columns */
	}

	.calendar-day {
		width: 100%;
		border-collapse: collapse;
	}

	.calendar-day th, .calendar-day td {
		border: 1px solid #ccc;
		padding: 10px;
		text-align: center;
		vertical-align: top;
	}

	.calendar-day .hour {
		width: 40px;
		background-color: #f9f9f9;
		text-align: center;
		padding: 10px;
		font-weight: bold;
	}

	.calendar-day .day-event {
		width: 100%;
		padding-left: 10px;
		text-align: left;
	}

	.event {
		background-color: #90caf9;
		padding: 5px;
		margin: 3px 0;
		border-radius: 4px;
	}

	.event-time {
		font-size: 0.8em;
		color: #555;
	}

	/* Basic styles for the event link */
	.calendar-month .event a,
	.calendar-week .event a {
		position: relative;
		text-decoration: none;
		color: #007bff;
	}

	/* Styles for the tooltip */
	.calendar-month .tooltiptext,
	.calendar-week .tooltiptext {
		visibility: hidden;
		width: 200px;
		background-color: rgba(0, 0, 0, 0.8);
		color: #fff;
		text-align: center;
		border-radius: 5px;
		padding: 10px;
		position: absolute;
		z-index: 1;
		bottom: 100%;
		left: 50%;
		margin-left: -100px;
		opacity: 0;
		transition: opacity 0.3s;
	}

	/* Displays the tooltip when hovering over the link */
	.calendar-month .event a:hover .tooltiptext,
	.calendar-week .event a:hover .tooltiptext {
		visibility: visible;
		opacity: 1;
	}

	.calendar-year {
	    display: flex;
	    flex-wrap: wrap;
	    gap: 20px;
	}

	.calendar-year-month {
		flex: 1 0 calc(33.33% - 20px); /* Three columns with spacing */
		width: 14.28%;
		border: 1px solid #ccc;
		padding: 10px;
		border-radius: 5px;
		box-sizing: border-box;
	}

	/* Media query to switch to two columns */
	@media (max-width: 1024px) {
		.calendar-year-month {
			flex: 1 0 calc(50% - 20px); /* Two columns */
		}
	}

	/* Media query to switch to one column */
	@media (max-width: 768px) {
		.calendar-year-month {
			flex: 1 0 100%; /* One column */
		}
	}
</style>

</head>
<body>

<div class="container">

  <?php 
	// Display the view switcher to toggle between month, week, and day views
	renderViewSwitcher($month, $year, $view, $lang, $translations);

	// Select and display the calendar view based on the user's choice (month, week, or day)
	if ($view == 'month') {

		// Display month navigation (buttons to go to the previous or next month)
		renderMonthNavigation($month, $year, $lang, $translations);

		// Display the month view with the events for the month
		renderMonthCalendar($month, $year, $events, $weekStart, $lang, $translations);

	} elseif ($view == 'week') {

		// Display week navigation (buttons to go to the previous or next week)
		renderWeekNavigation($year, $week, $lang, $translations);

		// Display the week view with the events for the week
		renderWeekView($month, $year, $week, $events, $weekStart, $lang, $translations, $workingStartTime, $workingEndTime);

	} elseif ($view == 'day') {

		// Display day navigation (buttons to go to the previous or next day)
		renderDayNavigation($month, $year, $day, $lang, $translations, $workingStartTime, $workingEndTime);

		// Display the day view with the events, including the hours of the day
		renderDayViewWithHours($month, $year, $day, $events, $lang, $translations);
		
	} elseif ($view == 'year') {

		// Displays the year navigation
		renderYearNavigation($year, $lang, $translations);

		// Display the annual calendar
		renderYearCalendar($year, $events, $weekStart, $lang, $translations);
	}
  ?>

</div>

</body>
</html>